(_api_state_vector)=
# State Vector
```{eval-rst}
.. autosummary::
    :toctree: generated/

    skretrieval.retrieval.statevector.StateVector

```

## State Elements
```{eval-rst}
.. autosummary::
    :toctree: generated/

    skretrieval.retrieval.statevector.StateVectorElement
    skretrieval.retrieval.statevector.constituent.StateVectorElementConstituent
```
